#include <Servo.h>

// Define servo pins
#define RIGHT_SERVO_PIN 8  // Right motor
#define LEFT_SERVO_PIN  9  // Left motor

// Define IR sensor pins
#define LEFT_SENSOR_PIN  A0
#define RIGHT_SENSOR_PIN A1

Servo rightServo;
Servo leftServo;

// Calibration values (adjust these for your specific sensors and line)
int leftSensorBlack = 300;   // New black value
int leftSensorWhite = 40;   // New white value
int rightSensorBlack = 300;  // New black value
int rightSensorWhite = 40; // New white value

// Motor speeds (adjust these for your robot)
int rightForwardSpeed = 85; //  Reduced from 70 by ~20%
int leftForwardSpeed = 95; // Reduced from 110 by ~20%
int stopSpeed = 90;     // Value to stop the servos
int turnSpeed = 95;    // Reduced from 150 by ~15%
int slowSpeed = 95;     // Reduced from 80 by ~15%

void setup() {
  // Attach servos
  rightServo.attach(RIGHT_SERVO_PIN);
  leftServo.attach(LEFT_SERVO_PIN);

  // Initialize serial communication for debugging
  Serial.begin(9600);
}

void loop() {
  // Read sensor values
  int leftValue = analogRead(LEFT_SENSOR_PIN);
  int rightValue = analogRead(RIGHT_SENSOR_PIN);

  // Print sensor values for debugging
  Serial.print("Left: ");
  Serial.print(leftValue);
  Serial.print("  Right: ");
  Serial.println(rightValue);

  // Line following logic (assuming black line, adjust as needed)
  if (leftValue > leftSensorWhite && rightValue > rightSensorWhite) {
    // Both sensors on black line: Move forward
    rightServo.write(rightForwardSpeed);
    leftServo.write(leftForwardSpeed);
  } else if (leftValue < leftSensorWhite) {
    // Left sensor on white, right sensor on black: Turn right - changed logic
    rightServo.write(turnSpeed);
    leftServo.write(slowSpeed);
  } else if (rightValue < rightSensorWhite) {
    // Right sensor on white, left sensor on black: Turn left - changed logic
    rightServo.write(slowSpeed);
    leftServo.write(turnSpeed);
  } else {
    // Both sensors on black:  Lost the line, stop or continue last direction - changed logic
    //rightServo.write(stopSpeed);  // Stop
    //leftServo.write(stopSpeed);   // Stop
    rightServo.write(rightForwardSpeed); // Continue
    leftServo.write(leftForwardSpeed);
  }
  delay(10);
}
